aboutsummaryrefslogtreecommitdiffstats
path: root/src/intel/vulkan/anv_entrypoints_gen.py
diff options
context:
space:
mode:
authorAnuj Phogat <[email protected]>2017-05-26 09:11:20 -0700
committerAnuj Phogat <[email protected]>2017-06-22 14:17:45 -0700
commitac6bc0e0345f933cd7d6bb6fd8354302cdfe9550 (patch)
tree1deaca7dc5f1dac94c8b6e39739dd8746064a0fe /src/intel/vulkan/anv_entrypoints_gen.py
parentc17e214a6bf1da97c78fa7a6192cb1b498b773a1 (diff)
anv/cnl: Generate and use gen10 functions
Signed-off-by: Anuj Phogat <[email protected]> Reviewed-by: Jason Ekstrand <[email protected]>
Diffstat (limited to 'src/intel/vulkan/anv_entrypoints_gen.py')
-rw-r--r--src/intel/vulkan/anv_entrypoints_gen.py7
1 files changed, 6 insertions, 1 deletions
diff --git a/src/intel/vulkan/anv_entrypoints_gen.py b/src/intel/vulkan/anv_entrypoints_gen.py
index 2168b7f64f0..f1b4b0c95e1 100644
--- a/src/intel/vulkan/anv_entrypoints_gen.py
+++ b/src/intel/vulkan/anv_entrypoints_gen.py
@@ -91,6 +91,7 @@ TEMPLATE_H = Template(textwrap.dedent("""\
${type_} gen75_${name}(${args});
${type_} gen8_${name}(${args});
${type_} gen9_${name}(${args});
+ ${type_} gen10_${name}(${args});
% if guard is not None:
#endif // ${guard}
% endif
@@ -152,7 +153,7 @@ TEMPLATE_C = Template(textwrap.dedent(u"""\
* either pick the correct entry point.
*/
% for layer in ['anv', 'gen7', 'gen75', 'gen8', 'gen9']:
% for type_, name, args, _, _, guard in entrypoints:
% if guard is not None:
#ifdef ${guard}
@@ -184,6 +185,10 @@ TEMPLATE_C = Template(textwrap.dedent(u"""\
}
switch (devinfo->gen) {
+ case 10:
+ if (gen10_layer.entrypoints[index])
+ return gen10_layer.entrypoints[index];
+ /* fall through */
case 9:
if (gen9_layer.entrypoints[index])
return gen9_layer.entrypoints[index];
@@ -152,7 +153,7 @@ TEMPLATE_C = Template(textwrap.dedent(u"""\
* either pick the correct entry point.
*/
- % for layer in ['anv', 'gen7', 'gen75', 'gen8', 'gen9']:
+ % for layer in ['anv', 'gen7', 'gen75', 'gen8', 'gen9', 'gen10']:
% for type_, name, args, _, _, guard in entrypoints:
% if guard is not None: